@@ -16,9 +16,9 @@ pub struct Item<'grammar, L: Lookahead> {
     pub lookahead: L,
 }
 
-pub type LR0Item<'grammar> = Item<'grammar, Nil>;
+pub type Lr0Item<'grammar> = Item<'grammar, Nil>;
 
-pub type LR1Item<'grammar> = Item<'grammar, TokenSet>;
+pub type Lr1Item<'grammar> = Item<'grammar, TokenSet>;
 
 impl<'grammar> Item<'grammar, Nil> {
     pub fn lr0(production: &'grammar Production, index: usize) -> Self {
@@ -60,7 +60,7 @@ impl<'grammar, L: Lookahead> Item<'grammar, L> {
         }
     }
 
-    pub fn to_lr0(&self) -> LR0Item<'grammar> {
+    pub fn to_lr0(&self) -> Lr0Item<'grammar> {
         Item {
             production: self.production,
             index: self.index,
@@ -74,14 +74,7 @@ impl<'grammar, L: Lookahead> Item<'grammar, L> {
 
     pub fn can_shift_nonterminal(&self, nt: &NonterminalString) -> bool {
         match self.shift_symbol() {
-            Some((Symbol::Nonterminal(shifted), _)) => shifted == *nt,
-            _ => false,
-        }
-    }
-
-    pub fn can_shift_terminal(&self, term: &TerminalString) -> bool {
-        match self.shift_symbol() {
-            Some((Symbol::Terminal(shifted), _)) => shifted == *term,
+            Some((Symbol::Nonterminal(shifted), _)) => shifted == nt,
             _ => false,
         }
     }
@@ -90,10 +83,10 @@ impl<'grammar, L: Lookahead> Item<'grammar, L> {
         self.index == self.production.symbols.len()
     }
 
-    pub fn shifted_item(&self) -> Option<(Symbol, Item<'grammar, L>)> {
+    pub fn shifted_item(&self) -> Option<(&Symbol, Item<'grammar, L>)> {
         if self.can_shift() {
             Some((
-                self.production.symbols[self.index].clone(),
+                &self.production.symbols[self.index],
                 Item {
                     production: self.production,
                     index: self.index + 1,
@@ -105,10 +98,10 @@ impl<'grammar, L: Lookahead> Item<'grammar, L> {
         }
     }
 
-    pub fn shift_symbol(&self) -> Option<(Symbol, &[Symbol])> {
+    pub fn shift_symbol(&self) -> Option<(&Symbol, &[Symbol])> {
         if self.can_shift() {
             Some((
-                self.production.symbols[self.index].clone(),
+                &self.production.symbols[self.index],
                 &self.production.symbols[self.index + 1..],
             ))
         } else {
@@ -126,9 +119,9 @@ pub struct Items<'grammar, L: Lookahead> {
 }
 
 #[allow(dead_code)]
-pub type LR0Items<'grammar> = Items<'grammar, Nil>;
+pub type Lr0Items<'grammar> = Items<'grammar, Nil>;
 #[allow(dead_code)]
-pub type LR1Items<'grammar> = Items<'grammar, TokenSet>;
+pub type Lr1Items<'grammar> = Items<'grammar, TokenSet>;
 
 #[derive(Clone, Debug)]
 pub struct State<'grammar, L: Lookahead> {
@@ -139,8 +132,8 @@ pub struct State<'grammar, L: Lookahead> {
     pub gotos: Map<NonterminalString, StateIndex>,
 }
 
-pub type LR0State<'grammar> = State<'grammar, Nil>;
-pub type LR1State<'grammar> = State<'grammar, TokenSet>;
+pub type Lr0State<'grammar> = State<'grammar, Nil>;
+pub type Lr1State<'grammar> = State<'grammar, TokenSet>;
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum Action<'grammar> {
@@ -164,8 +157,8 @@ pub struct Conflict<'grammar, L> {
 }
 
 #[allow(dead_code)]
-pub type LR0Conflict<'grammar> = Conflict<'grammar, Nil>;
-pub type LR1Conflict<'grammar> = Conflict<'grammar, TokenSet>;
+pub type Lr0Conflict<'grammar> = Conflict<'grammar, Nil>;
+pub type Lr1Conflict<'grammar> = Conflict<'grammar, TokenSet>;
 
 #[derive(Debug)]
 pub struct TableConstructionError<'grammar, L: Lookahead> {
@@ -177,11 +170,11 @@ pub struct TableConstructionError<'grammar, L: Lookahead> {
     pub conflicts: Vec<Conflict<'grammar, L>>,
 }
 
-pub type LR0TableConstructionError<'grammar> = TableConstructionError<'grammar, Nil>;
-pub type LR1TableConstructionError<'grammar> = TableConstructionError<'grammar, TokenSet>;
-pub type LRResult<'grammar, L> =
+pub type Lr0TableConstructionError<'grammar> = TableConstructionError<'grammar, Nil>;
+pub type Lr1TableConstructionError<'grammar> = TableConstructionError<'grammar, TokenSet>;
+pub type LrResult<'grammar, L> =
     Result<Vec<State<'grammar, L>>, TableConstructionError<'grammar, L>>;
-pub type LR1Result<'grammar> = LRResult<'grammar, TokenSet>;
+pub type Lr1Result<'grammar> = LrResult<'grammar, TokenSet>;
 
 impl<'grammar, L: Lookahead> Debug for Item<'grammar, L> {
     fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error> {
@@ -200,7 +193,7 @@ impl<'grammar, L: Lookahead> Debug for Item<'grammar, L> {
 impl Display for Token {
     fn fmt(&self, fmt: &mut Formatter) -> Result<(), Error> {
         match *self {
-            Token::EOF => write!(fmt, "EOF"),
+            Token::Eof => write!(fmt, "Eof"),
             Token::Error => write!(fmt, "Error"),
             Token::Terminal(ref s) => write!(fmt, "{}", s),
         }
