@@ -2,7 +2,6 @@
 
 use crate::collections::{set, Set};
 use crate::grammar::repr::*;
-use itertools::Itertools;
 use crate::lr1::core::*;
 use crate::lr1::example::{Example, ExampleStyles, ExampleSymbol};
 use crate::lr1::first::FirstSets;
@@ -11,20 +10,25 @@ use crate::lr1::trace::Tracer;
 use crate::message::builder::{BodyCharacter, Builder, Character, MessageBuilder};
 use crate::message::Message;
 use crate::tls::Tls;
+use itertools::Itertools;
 
 #[cfg(test)]
 mod test;
 
-pub fn report_error(grammar: &Grammar, error: &LR1TableConstructionError) -> Vec<Message> {
+pub fn report_error<E>(
+    grammar: &Grammar,
+    error: &Lr1TableConstructionError,
+    reporter: impl FnMut(Message) -> Result<(), E>,
+) -> Result<(), E> {
     let mut cx = ErrorReportingCx::new(grammar, &error.states, &error.conflicts);
-    cx.report_errors()
+    cx.report_errors(reporter)
 }
 
 struct ErrorReportingCx<'cx, 'grammar: 'cx> {
     grammar: &'grammar Grammar,
     first_sets: FirstSets,
-    states: &'cx [LR1State<'grammar>],
-    conflicts: &'cx [LR1Conflict<'grammar>],
+    states: &'cx [Lr1State<'grammar>],
+    conflicts: &'cx [Lr1Conflict<'grammar>],
 }
 
 #[derive(Debug)]
@@ -75,8 +79,8 @@ type TokenConflict<'grammar> = Conflict<'grammar, Token>;
 impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
     fn new(
         grammar: &'grammar Grammar,
-        states: &'cx [LR1State<'grammar>],
-        conflicts: &'cx [LR1Conflict<'grammar>],
+        states: &'cx [Lr1State<'grammar>],
+        conflicts: &'cx [Lr1Conflict<'grammar>],
     ) -> Self {
         ErrorReportingCx {
             grammar,
@@ -86,11 +90,14 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
         }
     }
 
-    fn report_errors(&mut self) -> Vec<Message> {
-        token_conflicts(self.conflicts)
-            .iter()
-            .map(|conflict| self.report_error(conflict))
-            .collect()
+    fn report_errors<E>(
+        &mut self,
+        mut reporter: impl FnMut(Message) -> Result<(), E>,
+    ) -> Result<(), E> {
+        for conflict in &token_conflicts(self.conflicts) {
+            reporter(self.report_error(conflict))?
+        }
+        Ok(())
     }
 
     fn report_error(&mut self, conflict: &TokenConflict<'grammar>) -> Message {
@@ -218,7 +225,7 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
                 .styled(Tls::session().cursor_symbol)
                 .punctuated(","),
             Token::Error => builder.text("If an error has been found,"),
-            Token::EOF => builder.text("If the end of the input is reached,"),
+            Token::Eof => builder.text("If the end of the input is reached,"),
         };
 
         let builder = builder
@@ -683,8 +690,8 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
         shift_upcoming
             .iter()
             .zip(reduce_upcoming)
-            .filter_map(|(shift_sym, reduce_sym)| match (shift_sym, reduce_sym) {
-                (&ExampleSymbol::Symbol(ref shift_sym), &ExampleSymbol::Symbol(ref reduce_sym)) => {
+            .find_map(|(shift_sym, reduce_sym)| match (shift_sym, reduce_sym) {
+                (ExampleSymbol::Symbol(shift_sym), ExampleSymbol::Symbol(reduce_sym)) => {
                     if shift_sym == reduce_sym {
                         // same symbol on both; we'll be able to shift them
                         None
@@ -694,13 +701,9 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
                         // consider a suffix matching epsilon to be
                         // potentially overlapping, though we could
                         // supply the actual lookahead for more precision.
-                        let shift_first = self.first_sets.first0(&[shift_sym.clone()]);
-                        let reduce_first = self.first_sets.first0(&[reduce_sym.clone()]);
-                        if shift_first.is_disjoint(&reduce_first) {
-                            Some(true)
-                        } else {
-                            Some(false)
-                        }
+                        let shift_first = self.first_sets.first0(std::iter::once(shift_sym));
+                        let reduce_first = self.first_sets.first0(std::iter::once(reduce_sym));
+                        Some(shift_first.is_disjoint(&reduce_first))
                     }
                 }
                 _ => {
@@ -711,7 +714,6 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
                     Some(false)
                 }
             })
-            .next()
             .unwrap_or(false)
     }
 
@@ -749,9 +751,9 @@ impl<'cx, 'grammar> ErrorReportingCx<'cx, 'grammar> {
 
     fn conflicting_shift_items(
         &self,
-        state: &LR1State<'grammar>,
+        state: &Lr1State<'grammar>,
         conflict: &TokenConflict<'grammar>,
-    ) -> Set<LR0Item<'grammar>> {
+    ) -> Set<Lr0Item<'grammar>> {
         // Lookahead must be a terminal, not EOF.
         // Find an item J like `Bar = ... (*) L ...`.
         let lookahead = Symbol::Terminal(conflict.lookahead.unwrap_terminal().clone());
