@@ -1,9 +1,9 @@
 use crate::collections::{Map, Multimap, Set};
-use ena::unify::InPlaceUnificationTable;
-use crate::lr1::core::{Action, LR1State, StateIndex};
+use crate::lr1::core::{Action, Lr1State, StateIndex};
 use crate::lr1::lane_table::construct::state_set::StateSet;
 use crate::lr1::lane_table::table::context_set::ContextSet;
 use crate::lr1::lane_table::table::LaneTable;
+use ena::unify::InPlaceUnificationTable;
 
 /// The "merge" phase of the algorithm is described in "Step 3c" of
 /// [the README][r].  It consists of walking through the various
@@ -16,7 +16,7 @@ use crate::lr1::lane_table::table::LaneTable;
 /// [r]: ../README.md
 pub struct Merge<'m, 'grammar: 'm> {
     table: &'m LaneTable<'grammar>,
-    states: &'m mut Vec<LR1State<'grammar>>,
+    states: &'m mut Vec<Lr1State<'grammar>>,
     visited: Set<StateIndex>,
     original_indices: Map<StateIndex, StateIndex>,
     clones: Multimap<StateIndex, Vec<StateIndex>>,
@@ -28,7 +28,7 @@ impl<'m, 'grammar> Merge<'m, 'grammar> {
     pub fn new(
         table: &'m LaneTable<'grammar>,
         unify: &'m mut InPlaceUnificationTable<StateSet>,
-        states: &'m mut Vec<LR1State<'grammar>>,
+        states: &'m mut Vec<Lr1State<'grammar>>,
         state_sets: &'m mut Map<StateIndex, StateSet>,
         inconsistent_state: StateIndex,
     ) -> Self {
@@ -101,7 +101,7 @@ impl<'m, 'grammar> Merge<'m, 'grammar> {
                     self.clones
                         .get(&successor)
                         .into_iter()
-                        .flat_map(|clones| clones) // get() returns an Option<Set>
+                        .flatten() // get() returns an Option<Set>
                         .cloned()
                         .find(|&successor1| context_sets.union(state, successor1))
                 };
@@ -143,7 +143,8 @@ impl<'m, 'grammar> Merge<'m, 'grammar> {
     fn clone(&mut self, state: StateIndex) -> StateIndex {
         // create a new state with same contents as the old one
         let new_index = StateIndex(self.states.len());
-        let new_state = self.states[state.0].clone();
+        let mut new_state = self.states[state.0].clone();
+        new_state.index = new_index;
         self.states.push(new_state);
 
         // track the original index and clones
