@@ -1,12 +1,12 @@
-use grammar::consts::INLINE;
-use grammar::parse_tree::{
+use crate::grammar::consts::INLINE;
+use crate::grammar::parse_tree::{
     ActionKind, Alternative, Annotation, Condition, ConditionOp, ExprSymbol, Grammar, GrammarItem,
     MacroSymbol, Name, NonterminalData, NonterminalString, Path, RepeatOp, RepeatSymbol, Span,
     Symbol, SymbolKind, TerminalLiteral, TerminalString, TypeRef, Visibility,
 };
-use normalize::norm_util::{self, Symbols};
-use normalize::resolve;
-use normalize::{NormError, NormResult};
+use crate::normalize::norm_util::{self, Symbols};
+use crate::normalize::resolve;
+use crate::normalize::{NormError, NormResult};
 use regex::Regex;
 use std::collections::{HashMap, HashSet};
 use std::mem;
@@ -201,6 +201,7 @@ impl MacroExpander {
                 expr: self.macro_expand_expr_symbol(&args, &alternative.expr),
                 condition: None,
                 action: alternative.action.clone(),
+                annotations: alternative.annotations.clone(),
             });
         }
 
@@ -233,6 +234,9 @@ impl MacroExpander {
     ) -> TypeRef {
         match *type_ref {
             TypeRef::Tuple(ref trs) => TypeRef::Tuple(self.macro_expand_type_refs(args, trs)),
+            TypeRef::Slice(ref tr) => {
+                TypeRef::Slice(Box::new(self.macro_expand_type_ref(args, tr)))
+            }
             TypeRef::Nominal {
                 ref path,
                 ref types,
@@ -311,11 +315,11 @@ impl MacroExpander {
     }
 
     fn re_match(&self, span: Span, lhs: &Atom, regex: &Atom) -> NormResult<bool> {
-        let re = match Regex::new(&regex) {
+        let re = match Regex::new(regex) {
             Ok(re) => re,
             Err(err) => return_err!(span, "invalid regular expression `{}`: {}", regex, err),
         };
-        Ok(re.is_match(&lhs))
+        Ok(re.is_match(lhs))
     }
 
     fn macro_expand_symbols(
@@ -387,7 +391,7 @@ impl MacroExpander {
     fn expand_expr_symbol(&mut self, span: Span, expr: ExprSymbol) -> NormResult<GrammarItem> {
         let name = NonterminalString(Atom::from(expr.canonical_form()));
 
-        let ty_ref =
+        let (action, ty_ref) =
             match norm_util::analyze_expr(&expr) {
                 Symbols::Named(names) => {
                     let (_, ref ex_id, ex_sym) = names[0];
@@ -396,10 +400,17 @@ impl MacroExpander {
                     "named symbols like `{}:{}` are only allowed at the top-level of a nonterminal",
                     ex_id, ex_sym)
                 }
-                Symbols::Anon(syms) => maybe_tuple(
-                    syms.into_iter()
-                        .map(|(_, s)| TypeRef::OfSymbol(s.kind.clone()))
-                        .collect(),
+                Symbols::Anon(syms) => (
+                    if syms.len() == 1 {
+                        action("<>")
+                    } else {
+                        action("(<>)")
+                    },
+                    maybe_tuple(
+                        syms.into_iter()
+                            .map(|(_, s)| TypeRef::OfSymbol(s.kind.clone()))
+                            .collect(),
+                    ),
                 ),
             };
 
@@ -414,7 +425,8 @@ impl MacroExpander {
                 span,
                 expr,
                 condition: None,
-                action: action("(<>)"),
+                action,
+                annotations: Vec::new(),
             }],
         }))
     }
@@ -443,7 +455,7 @@ impl MacroExpander {
 
                 let plus_repeat = Box::new(RepeatSymbol {
                     op: RepeatOp::Plus,
-                    symbol: repeat.symbol.clone(),
+                    symbol: repeat.symbol,
                 });
 
                 Ok(GrammarItem::Nonterminal(NonterminalData {
@@ -459,7 +471,8 @@ impl MacroExpander {
                             span,
                             expr: ExprSymbol { symbols: vec![] },
                             condition: None,
-                            action: action("vec![]"),
+                            action: action("alloc::vec![]"),
+                            annotations: vec![],
                         },
                         // X* = <v:X+>
                         Alternative {
@@ -478,6 +491,7 @@ impl MacroExpander {
                             },
                             condition: None,
                             action: action("v"),
+                            annotations: vec![],
                         },
                     ],
                 }))
@@ -505,7 +519,8 @@ impl MacroExpander {
                                 symbols: vec![repeat.symbol.clone()],
                             },
                             condition: None,
-                            action: action("vec![<>]"),
+                            action: action("alloc::vec![<>]"),
+                            annotations: vec![],
                         },
                         // X+ = <v:X+> <e:X>
                         Alternative {
@@ -524,15 +539,13 @@ impl MacroExpander {
                                     ),
                                     Symbol::new(
                                         span,
-                                        SymbolKind::Name(
-                                            Name::immut(e),
-                                            Box::new(repeat.symbol.clone()),
-                                        ),
+                                        SymbolKind::Name(Name::immut(e), Box::new(repeat.symbol)),
                                     ),
                                 ],
                             },
                             condition: None,
                             action: action("{ let mut v = v; v.push(e); v }"),
+                            annotations: vec![],
                         },
                     ],
                 }))
@@ -557,10 +570,11 @@ impl MacroExpander {
                         Alternative {
                             span,
                             expr: ExprSymbol {
-                                symbols: vec![repeat.symbol.clone()],
+                                symbols: vec![repeat.symbol],
                             },
                             condition: None,
                             action: action("Some(<>)"),
+                            annotations: vec![],
                         },
                         // X? = { => None; }
                         Alternative {
@@ -568,6 +582,7 @@ impl MacroExpander {
                             expr: ExprSymbol { symbols: vec![] },
                             condition: None,
                             action: action("None"),
+                            annotations: vec![],
                         },
                     ],
                 }))
@@ -594,6 +609,7 @@ impl MacroExpander {
                 expr: ExprSymbol { symbols: vec![] },
                 condition: None,
                 action: Some(action),
+                annotations: vec![],
             }],
         }))
     }
