@@ -117,8 +117,8 @@ fn match_mappings() {
     check_intern_token(
         r#"grammar; match { r"(?i)begin" => "BEGIN" } else { "abc" => ALPHA } X = "BEGIN" ALPHA;"#,
         vec![
-            ("BEGIN", r##"Some(("BEGIN", "BEGIN"))"##),
-            ("begin", r##"Some(("BEGIN", "begin"))"##),
+            ("BEGIN", r#"Some(("BEGIN", "BEGIN"))"#),
+            ("begin", r#"Some(("BEGIN", "begin"))"#),
             ("abc", r#"Some((ALPHA, "abc"))"#),
         ],
     );
@@ -133,8 +133,8 @@ fn match_precedence() {
     check_intern_token(
         r#"grammar; match { r"(?i)begin" => "BEGIN" } else { r"\w+" => ID } X = ();"#,
         vec![
-            ("BEGIN", r##"Some(("BEGIN", "BEGIN"))"##),
-            ("begin", r##"Some(("BEGIN", "begin"))"##),
+            ("BEGIN", r#"Some(("BEGIN", "BEGIN"))"#),
+            ("begin", r#"Some(("BEGIN", "begin"))"#),
             ("abc", r#"Some((ID, "abc"))"#),
         ],
     );
@@ -169,11 +169,41 @@ fn match_catch_all() {
     assert!(validate_grammar(grammar).is_ok())
 }
 
+/// Test that a `catch-all` can be use in the first `match` arm.
+/// Before the pull request to close [issue 325](https://github.com/lalrpop/lalrpop/issues/325),
+/// the usage of the `catch-all` symbol was not allowed in the first arm of a `match` block.
+#[test]
+fn match_catch_all_in_first_arm() {
+    let grammar = r#"
+        grammar;
+        match {
+            r"[a-z]",
+            _
+        } else {
+            r"[[:word:]]+"
+        }
+        pub Term = {
+            Num,
+            "(" <Term> ")",
+            r"[[:word:]]+" => format!("Id({})", <>),
+        };
+        Num: String = r"[0-9]+" => <>.to_string();
+"#;
+    assert!(validate_grammar(grammar).is_ok());
+    check_intern_token(
+        grammar,
+        vec![
+            ("x", r##"Some((r#"[a-z]"#, "x"))"##),
+            ("xy", r##"Some((r#"[[:word:]]+"#, "xy"))"##),
+        ],
+    );
+}
+
 #[test]
 // This test requires regex's unicode case support
 #[cfg_attr(not(feature = "unicode"), ignore)]
 fn complex_match() {
-    let grammar = r##"
+    let grammar = r#"
         grammar;
         match {
             "abc"        => "ABC",
@@ -183,7 +213,7 @@ fn complex_match() {
         pub Query: String = {
             "ABC" BEGIN => String::from("Success")
         };
-"##;
+"#;
     assert!(validate_grammar(grammar).is_ok())
 }
 
