@@ -1,4 +1,3 @@
-use diff;
 use crate::grammar::parse_tree as pt;
 use crate::grammar::repr as r;
 use crate::normalize::NormError;
@@ -44,32 +43,31 @@ pub fn compare<D: Debug, E: Debug>(actual: D, expected: E) {
             }
         }
 
-        assert!(false);
+        panic!();
     }
 
     /// Ignore differences in `Span` values, by replacing them all with fixed
     /// dummy text.
-    fn normalize<'t>(with_spans: &'t str) -> std::borrow::Cow<'t, str> {
-        SPAN.with(|span| {
-            span.replace_all(&with_spans, "Span(..)")
-        })
+    fn normalize(with_spans: &str) -> std::borrow::Cow<'_, str> {
+        SPAN.with(|span| span.replace_all(with_spans, "Span(..)"))
     }
 }
 
 pub fn normalized_grammar(s: &str) -> r::Grammar {
-    crate::normalize::normalize_without_validating(crate::parser::parse_grammar(s).unwrap()).unwrap()
+    crate::normalize::normalize_without_validating(crate::parser::parse_grammar(s).unwrap())
+        .unwrap()
 }
 
 pub fn check_norm_err(expected_err: &str, span: &str, err: NormError) {
     let expected_err = Regex::new(expected_err).unwrap();
-    let start_index = span.find("~").unwrap();
-    let end_index = span.rfind("~").unwrap() + 1;
-    assert!(start_index <= end_index);
-    assert_eq!(err.span, pt::Span(start_index, end_index));
+    let start_index = span.find('~').unwrap();
+    let end_index = span.rfind('~').unwrap() + 1;
     assert!(
         expected_err.is_match(&err.message),
         "unexpected error text `{}`, which did not match regular expression `{}`",
         err.message,
         expected_err
     );
+    assert!(start_index <= end_index);
+    assert_eq!(err.span, pt::Span(start_index, end_index));
 }
